Name:           python-tabulate
Version:        0.8.10
Release:        2%{?dist}
Summary:        Pretty-print tabular data in Python, a library and a command-line utility

# SPDX
License:        MIT
URL:            https://github.com/astanin/python-tabulate
Source0:        %{pypi_source tabulate}
# Hand-written for Fedora based on --help output using groff_man(7) format
Source1:        tabulate.1

BuildArch:      noarch

BuildRequires:  python3-devel

# setup.py (with fallback to distutils)
BuildRequires:  python3-setuptools

# “widechars” extra (setup.py: extras_require)
BuildRequires:  python3dist(wcwidth)

# Additional test dependencies
BuildRequires:  python3dist(numpy)
BuildRequires:  python3dist(pandas)
BuildRequires:  python3dist(pytest)

%global _description %{expand:
The main use cases of the library are:
• printing small tables without hassle: just one function call, formatting is
  guided by the data itself
• authoring tabular data for lightweight plain-text markup: multiple output
  formats suitable for further editing or transformation
• readable presentation of mixed textual and numeric data: smart column
  alignment, configurable number formatting, alignment by a decimal point}

%description %{_description}


%package -n python3-tabulate
Summary:        %{summary}

%py_provides python3-tabulate

%description -n python3-tabulate %{_description}


%prep
%autosetup -n tabulate-%{version}


%build
%py3_build


%install
%py3_install

install -t '%{buildroot}%{_mandir}/man1' -D -m 0644 -p '%{SOURCE1}'


%check
%pytest --doctest-modules --ignore benchmark.py


%files -n python3-tabulate
%license LICENSE
%doc CHANGELOG
%doc README.md

%{python3_sitelib}/tabulate-%{version}-py%{python3_version}.egg-info/
%pycached %{python3_sitelib}/tabulate.py

%{_bindir}/tabulate
%{_mandir}/man1/tabulate.1*


%changelog
* Mon Jan 30 2023 Miro Hrončok <mhroncok@redhat.com> - 0.8.10-2
- Rebuilt to change Python shebangs to /usr/bin/python3.6 on EPEL 8

* Tue Oct 25 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.8.10-1
- Update to 0.8.10 and add a man page

* Tue Oct 25 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.8.3-9
- Fix out-of-order changelog and incomplete version update
- Modernize packaging and drop EPEL7 conditionals

* Sun Sep 15 2019 Raphael Groner <projects.rg@smart.ms> - 0.8.3-8
- make sure the executables are owned by py3, rhbz#1750911

* Sat May 04 2019 Raphael Groner <projects.rg@smart.ms> - 0.8.3-7
- epel: (re-)add properly subpackages for python2 and both python3 versions
- use macro for description

* Thu Feb 21 2019 Raphael Groner <projects.rg@smart.ms> - 0.8.3-6
- fix merge conflicts

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jan 26 2019 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.8.3-3
- Remove py2 subpackage

* Sat Jan 26 2019 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.8.3-2
- Fix FTBFS

* Sat Jan 26 2019 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.8.3-1
- Update to latest upstream release

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 0.8.2-3
- Rebuilt for Python 3.7

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Jan 09 2018 Steve Traylen <steve.traylen@cern.ch> - 0.8.2-1
- Update to 0.8.2, Correct source URL.

* Tue Oct 03 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 0.8.1-1
- Update to 0.8.1
- Run more tests

* Sun Oct 01 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 0.8.0-1
- Update to 0.8.0

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.5-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.5-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 0.7.5-5
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.5-4
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sun Nov 29 2015 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.7.5-2
- Drop multiple versions of bins

* Tue Nov 24 2015 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.7.5-1
- Initial package
